#[non_exhaustive]pub enum DiffError {
OrderZero,
OrderUnsupported,
StepSizeZero,
IndexOutOfRange,
EmptyFunctionSet,
}Expand description
Errors from the differentiation modules (finite differences, autodiff, Jacobian, Hessian, Taylor approximation, and the curl/divergence operators).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OrderZero
The requested derivative order was zero.
OrderUnsupported
The requested derivative order is beyond what this differentiator supports.
StepSizeZero
A finite-difference step size of zero was supplied.
IndexOutOfRange
A variable index was outside the bounds of the point array.
EmptyFunctionSet
An empty set of functions was supplied where at least one was required.