MultiVariableSolver

Struct MultiVariableSolver 

pub struct MultiVariableSolver { /* private fields */ }
Implements the finite difference method for numerical differentation for multi-variable functions

Implementations

Source

impl MultiVariableSolver

pub fn get_step_size(&self) -> f64

Returns the step size

pub fn set_step_size(&mut self, step_size: f64)

Sets the step size

pub fn get_method(&self) -> FiniteDifferenceMode

Returns the chosen method of differentiation Possible choices are: Forward step, backward step and central step

pub fn set_method(&mut self, method: FiniteDifferenceMode)

Sets the method of differentiation Possible choices are: Forward step, backward step and central step

pub fn get_step_size_multiplier(&self) -> f64

Returns the chosen step size multiplier.

pub fn set_step_size_multiplier(&mut self, multiplier: f64)

Sets the chosen step size multiplier. The step size will be multiplied by this factor after every iteration This parameter only matters if you are interested in triple derivatives or higher

pub fn from_parameters( step: f64, method: FiniteDifferenceMode, multiplier: f64, ) -> Self

custom constructor, choose this for tweaking parameters if computing solutions for complex equations step: the desired step size for each iteration method: the desired method of differentiation: forward step, backward step or central step multiplier: default is 10.0, this is the factor by which we multiply the step size with on each iteration. Only matters for triple derivatives or higher